@@ -44,7 +44,7 @@ const Status  CEcaIAManager::Error(-2);
 CEcaIAManager::CEcaIAManager()
 {
   nTimerIDFinished = 0;
-  nSecondPosition = 0;
+  nMasterPosition = 0;
   bPlaying = false;
   //! \todo 󥻥åȥå "TEMP" ơ
   //! (ÿ֤)νԤ
@@ -128,7 +128,7 @@ CEcaIAManager::slotCreateNewChainsetup(const QString& strChainsetup)
 {
   slotReleaseCurrentChainsetup();
 
-  nSecondPosition = 0;
+  nMasterPosition = 0;
   QString strStatus = "cs-add " + strChainsetup;
   command(strStatus);
 }
@@ -154,14 +154,14 @@ CEcaIAManager::slotPlay(bool bRecord)
   case Error:
     return;
   case Finished:
-    slotSetPosition(0);
+    slotSetMasterPosition(0);
     break;
   default:
     break;
   }
 
   setIOToCurrentChainsetup(bRecord);
-  slotSetPosition(this->nSecondPosition);
+  slotSetMasterPosition(this->nMasterPosition);
 
   if ( !this->isValidChainsetup() ) {
     return;
@@ -183,7 +183,7 @@ CEcaIAManager::slotStop()
 {
   killTimers(); // kill all timers
   command("cs-disconnect");
-  slotSetPosition(this->nSecondPosition);
+  slotSetMasterPosition(this->nMasterPosition);
   // need to reconnect? !!!!!!!!!!!!!!!!!!!!!!!!!!!!
   removeTmpFiles();
   bPlaying = false;
@@ -202,7 +202,7 @@ CEcaIAManager::slotPause()
 /////////////////////////////////////////////////////////////////////////////
 
 void
-CEcaIAManager::slotSetPosition(const QTime& Time)
+CEcaIAManager::slotSetMasterPosition(const QTime& Time)
 {
   int nSec = 0;
 
@@ -210,24 +210,24 @@ CEcaIAManager::slotSetPosition(const QTime& Time)
   nSec += Time.minute() * 60;
   nSec += Time.second();
 
-  slotSetPosition(nSec);
+  slotSetMasterPosition(nSec);
 }
 
 /////////////////////////////////////////////////////////////////////////////
 
 void
-CEcaIAManager::slotSetPosition(int nSec)
+CEcaIAManager::slotSetMasterPosition(int nSec)
 {
   command(QString("cs-set-position %1").arg(nSec));
 
-  if ( nSec == this->nSecondPosition ) {
+  if ( nSec == this->nMasterPosition ) {
     return;
   }
 
-  this->nSecondPosition = nSec;
+  this->nMasterPosition = nSec;
 
   int nHour   = nSec / 3600;
-  emit positionChanged(QTime(nHour, 
+  emit masterPositionChanged(QTime(nHour, 
                              (nSec - (nHour * 3600)) / 60,
                              (nSec - (nHour * 3600)) % 60));
 }
@@ -240,14 +240,14 @@ CEcaIAManager::slotRewind(int nSecond)
   if ( isPlaying() ) {
     command("cs-rewind " + QString("%1").arg(nSecond));
   } else {
-    this->nSecondPosition -= nSecond;
-    if ( nSecondPosition < 0 ) {
-      this->nSecondPosition = 0;
+    this->nMasterPosition -= nSecond;
+    if ( nMasterPosition < 0 ) {
+      this->nMasterPosition = 0;
     }
-    int nHour   = this->nSecondPosition / 3600;
-    emit positionChanged(QTime(nHour,
-                               (this->nSecondPosition - (nHour * 3600)) / 60,
-                               (this->nSecondPosition - (nHour * 3600)) % 60));
+    int nHour   = this->nMasterPosition / 3600;
+    emit masterPositionChanged(QTime(nHour,
+                               (this->nMasterPosition - (nHour * 3600)) / 60,
+                               (this->nMasterPosition - (nHour * 3600)) % 60));
   }
 }
 
@@ -259,11 +259,11 @@ CEcaIAManager::slotForward(int nSecond)
   if ( isPlaying() ) {
     command("cs-forward " + QString("%1").arg(nSecond));
   } else {
-    this->nSecondPosition += nSecond;
-    int nHour   = this->nSecondPosition / 3600;
-    emit positionChanged(QTime(nHour,
-                               (this->nSecondPosition - (nHour * 3600)) / 60,
-                               (this->nSecondPosition - (nHour * 3600)) % 60));
+    this->nMasterPosition += nSecond;
+    int nHour   = this->nMasterPosition / 3600;
+    emit masterPositionChanged(QTime(nHour,
+                               (this->nMasterPosition - (nHour * 3600)) / 60,
+                               (this->nMasterPosition - (nHour * 3600)) % 60));
   }
 }
 
