@@ -69,9 +69,9 @@ WVoxStorm::WVoxStorm(QWidget *WidgetParent, const char *cName)
 
   setCentralWidget(VoxBase);
 
-  connect(VoxBase, SIGNAL(positionChanged(const QTime&)),
-          &EcaIAManager, SLOT(slotSetPosition(const QTime&)));
-  connect(&EcaIAManager, SIGNAL(positionChanged(const QTime&)),
+  connect(VoxBase, SIGNAL(masterPositionChanged(const QTime&)),
+          &EcaIAManager, SLOT(slotSetMasterPosition(const QTime&)));
+  connect(&EcaIAManager, SIGNAL(masterPositionChanged(const QTime&)),
           VoxBase, SLOT(slotChangePosition(const QTime&)));
   connect(&EcaIAManager, SIGNAL(finished()), this, SLOT(slotFinish()));
   connect(&EcaIAManager, SIGNAL(messageGenerated(const QString&)),
@@ -356,7 +356,7 @@ WVoxStorm::setupActions()
   menuBar()->insertItem(i18n("&Settings"), PopupMenu);
 
   QString strHelp =
-            i18n("VoxStorm 1.0\n\n"
+            i18n("VoxStorm 0.1\n\n"
                  "(C) 2003-2004 Tomoaki Murakami\n"
                  "solarisphere@yahoo.co.jp\n"
                  "Simple MTR using Ecasound on KDE\n");
@@ -385,10 +385,12 @@ bool
 WVoxStorm::queryClose()
 {
   if ( maybeSave() ) {
+    QApplication::setOverrideCursor(waitCursor);
     slotStop();
     if ( ToggleActionInteractive->isChecked() ) {
       EcaIAManager.slotReleaseCurrentChainsetup();
     }
+    QApplication::restoreOverrideCursor();
 
     return true;
   }
@@ -676,6 +678,7 @@ WVoxStorm::slotSaveAs()
 void
 WVoxStorm::slotPlay()
 {
+  QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
     EcaIAManager.slotRemoveAllChains();
     int nCount = VoxBase->getTrackCount();
@@ -692,6 +695,7 @@ WVoxStorm::slotPlay()
     }
   } else {
   }
+  QApplication::restoreOverrideCursor();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -707,10 +711,12 @@ WVoxStorm::slotRecord()
 void
 WVoxStorm::slotPause()
 {
+  QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
     EcaIAManager.slotPause();
     VoxBase->slotSetEnabledWidgets(WVoxBase::Pause);
   }
+  QApplication::restoreOverrideCursor();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -718,9 +724,11 @@ WVoxStorm::slotPause()
 void
 WVoxStorm::slotStop()
 {
+  QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
     EcaIAManager.slotStop();
   }
+  QApplication::restoreOverrideCursor();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -728,9 +736,11 @@ WVoxStorm::slotStop()
 void
 WVoxStorm::slotJumpToStart()
 {
+  QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
-    EcaIAManager.slotSetPosition(0);
+    EcaIAManager.slotSetMasterPosition(0);
   }
+  QApplication::restoreOverrideCursor();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -738,9 +748,11 @@ WVoxStorm::slotJumpToStart()
 void
 WVoxStorm::slotRewind()
 {
+  QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {    
     EcaIAManager.slotRewind(Preferences.iFrameSeconds);
   }
+  QApplication::restoreOverrideCursor();
 }
 
 /////////////////////////////////////////////////////////////////////////////
@@ -748,9 +760,11 @@ WVoxStorm::slotRewind()
 void
 WVoxStorm::slotForward()
 {
+  QApplication::setOverrideCursor(waitCursor);
   if ( ToggleActionInteractive->isChecked() ) {
     EcaIAManager.slotForward(Preferences.iFrameSeconds);
   }
+  QApplication::restoreOverrideCursor();
 }
 
 /////////////////////////////////////////////////////////////////////////////
