@@ -127,16 +127,16 @@ WVoxTrack::setupWidgets()
 
   // mute button
   PushButtonMute = new QPushButton(HBoxButtonBase);
+  PushButtonMute->setPaletteForegroundColor(QColor(0, 255, 0));
   PushButtonMute->setText("M");
-  PushButtonMute->setFont(QFont("Gothic", 8, QFont::Bold));
   PushButtonMute->setToggleButton(true);
   PushButtonMute->setOn(false);
   PushButtonMute->setMaximumWidth(20);
 
   // record button
   PushButtonRec = new QPushButton(HBoxButtonBase);
+  PushButtonRec->setPaletteForegroundColor(QColor(255, 0, 0));
   PushButtonRec->setText("R");
-  PushButtonRec->setFont(QFont("Gothic", 8, QFont::Bold));
   PushButtonRec->setToggleButton(true);
   PushButtonRec->setOn(false);
   PushButtonRec->setMaximumWidth(20);
@@ -159,7 +159,7 @@ WVoxTrack::setupPopupMenu()
 
   nMenuIDPlaybackDevice = PopupMenu->insertItem(i18n("Change &Playback Device..."),
                         this, SLOT(slotChangePlaybackDevice()));
-  nMenuIDRecordingDevice = PopupMenu->insertItem(i18n("Change &Recording Device..."), 
+  nMenuIDRecordingDevice = PopupMenu->insertItem(i18n("Change &Capture Device..."), 
                         this, SLOT(slotChangeRecordingDevice()));
 
   PopupMenu->insertSeparator();
@@ -169,11 +169,11 @@ WVoxTrack::setupPopupMenu()
 
   PopupMenu->insertSeparator();
 
-  nMenuIDStartPosition = PopupMenu->insertItem(i18n("Change Start P&osition..."),
+  nMenuIDStartPosition = PopupMenu->insertItem(i18n("Change &Start Position..."),
                         this, SLOT(slotChangeStartPosition()));
-  nMenuIDOffset = PopupMenu->insertItem(i18n("Change Offset from Origin..."),
+  nMenuIDOffset = PopupMenu->insertItem(i18n("Change &Offset from Origin..."),
                         this, SLOT(slotChangeOffset()));
-  nMenuIDLength = PopupMenu->insertItem(i18n("Change Playing Time Length..."),
+  nMenuIDLength = PopupMenu->insertItem(i18n("Change Playing Time &Length..."),
                         this, SLOT(slotChangeLength()));
 }
 
